@@ -6,7 +6,7 @@ module Test
   module Unit
     module Assertions
       def assert_warn(pattern, message = nil, &block)
-        class << (output = "")
+        class << (output = +"")
           alias write <<
         end
         stderr, $stderr = $stderr, output
@@ -49,6 +49,6 @@ end
 
 def sleep_until(time)
   if (s = time - Time.now) > 0
-    sleep s
+    sleep s + 0.01
   end
 end
